@@ -23,9 +23,12 @@ pub fn get(unfixed: &str, argv: &Vec<String>) -> Result<String, ParseError> {
 
     let mut res: Option<String> = None;
 
-    for arg in collected.iter() {
+    for (i, arg) in collected.iter().enumerate() {
         if arg == &fixed {
-            res = Some(arg.clone());
+            res = Some(match collected.get(i + 1) {
+                Some(some) => some.clone(),
+                None => return Err(ParseError::new(format!("no value for `{}`", unfixed))),
+            });
         }
     }
 
